guix-patches
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[bug#33186] [PATCH 6/7] gnu: slang: Use a correct location for terminfo


From: Mathieu Othacehe
Subject: [bug#33186] [PATCH 6/7] gnu: slang: Use a correct location for terminfo dirs.
Date: Sun, 28 Oct 2018 21:40:42 +0900

As termcap is disabled and no terminfo directory is given, slang is not able
to query terminal capabilities. Specifying a correct path for terminfo will
automatically disable termcap support in the configuration.

* gnu/packages/slang.scm (slang)[source]: Remove the snippet disabling
termcap.
[arguments]: Set MISC_TERMINFO_DIRS to a correct location.
---
 gnu/packages/slang.scm | 14 +++++++++++---
 1 file changed, 11 insertions(+), 3 deletions(-)

diff --git a/gnu/packages/slang.scm b/gnu/packages/slang.scm
index 24eb5fa13..185d44191 100644
--- a/gnu/packages/slang.scm
+++ b/gnu/packages/slang.scm
@@ -50,13 +50,21 @@
                '(begin
                   (substitute* "src/Makefile.in"
                     (("/bin/ln") "ln"))
-                  (substitute* "configure"
-                    (("-ltermcap") ""))
                   #t))))
     (build-system gnu-build-system)
     (arguments
      '(#:parallel-tests? #f
-       #:parallel-build? #f)) ; there's at least one race
+       #:parallel-build? #f  ; there's at least one race
+       #:phases
+       (modify-phases %standard-phases
+         (add-before 'configure 'substitute-before-config
+           (lambda* (#:key inputs #:allow-other-keys)
+             (let ((ncurses (assoc-ref inputs "ncurses")))
+               (substitute* "configure"
+                 (("MISC_TERMINFO_DIRS=\"\"")
+                  (string-append "MISC_TERMINFO_DIRS="
+                                 "\"" ncurses "/share/terminfo" "\"")))
+               #t))))))
     (inputs
      `(("readline" ,readline)
        ("zlib" ,zlib)
-- 
2.17.1






reply via email to

[Prev in Thread] Current Thread [Next in Thread]